# age and predictability experiment
# 30 young 30 old  participants

library(lme4)
library(lattice)
library(MASS)
library(plyr) 

rm(list=ls())

datafile = read.csv(file.choose(), sep = ",", dec = ".")

colnames(datafile)

##################################################################

col.subject = 1      # specify which column your participant number is in
col.condition = 5     #specify which column contains your condition number
col.stim = 2

# choose dependent variable
measure = "SFD"

# add to dataframe
datafile$depvar = datafile[,measure]

############

# Work out which colums the fixed and random factors are in

datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

# Let's make sure all the variables are from the correct class
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)

# check your data before starting analysing your data
str(datafile)


# get means, SDs, and SEs
# means for age groups    na.rm means (NA,remove)
(table1 <- ddply(datafile, .(age), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N)))

# means for display conditions
(table2 <- ddply(datafile, .(predictability), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N) ))

# means for different conditions
(table3 <- ddply(datafile, .(condition), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N) ))


################
# analyses
################

# set contrast for age group
contrasts(datafile$age) <- contr.sdif(2) 

# set contrast for predictability condition in this way, you'll get  (L-H):
contrasts(datafile$predictability) <- contr.sdif(2) 


#### Log ###
qqnorm(datafile$depvar)

qqnorm(log(datafile$depvar))

datafile$depvar = log(datafile$depvar)



######## analyse your data#########

####Sentence analysis (just analysis age effect)
depvar.lmer1 = lmer(depvar ~ age  + (1|participant) + (1|item), datafile)
summary(depvar.lmer1, corr = FALSE)


####Local analysis(age and predictability effect)
# attention: using the maximun structure if it is possible!
depvar.lmer1 = lmer(depvar ~ age * predictability + (1+predictability|participant) + (1+predictability|item), datafile)
summary(depvar.lmer1, corr = FALSE)


# if the maximun structure model cannot be converged, then using the simplfied model: 
depvar.lmer2 = lmer(depvar ~ age * predictability + (1|participant) + (1|item), datafile)
summary(depvar.lmer2, corr = FALSE)



# analyse your binomial data (0,1)
# attention: using the maximun structure if it is possible!
depvar.glmer1 = glmer(depvar ~ age * predictability + (1+predictability|participant) + (1+predictability|item), datafile, family=binomial)
summary(depvar.glmer1, corr = FALSE)

# if the maximun structure model cannot be converged, then using the simplfied one: 
depvar.glmer2 = glmer(depvar ~ age * predictability + (1|participant) + (1|item), datafile, family=binomial)
summary(depvar.glmer2, corr = FALSE)




###################################################
# then investigate simple effects of interactions if you have

# set contrast for your condition 
# using the contrast below, you can examine you interaction by comparing age group effects under each spacing condition
contrast.matrix <- matrix(c(   
  -1, +1, 0, 0,        # o h vs l
  0, 0, -1, +1), 4, 2, # y h vs l
  dimnames=list(c("O_H", "O_L", "Y_H", "Y_L"), 
                c("O_HvsL", "Y_HvsL")))

# Perform some magic (needs to inverse it before assigning to the contrasts)
inv.contrast.matrix <- matrix(t(ginv(contrast.matrix)), 4, 2,
                              dimnames=list(c("O_H", "O_L", "Y_H", "Y_L"), 
                                            c("O_HvsL", "Y_HvsL")))
(contrasts(datafile$condition) <- fractions(inv.contrast.matrix))


#### analyse your data###
depvar.lmer1 = lmer(depvar ~ condition + (1+predictability|participant) + (1+predictability|item), datafile)
summary(depvar.lmer1, corr = FALSE)


#simplfied one:
depvar.lmer2 = lmer(depvar ~ condition + (1|participant) + (1|item), datafile)
summary(depvar.lmer2, corr = FALSE)



